@@ -16,11 +16,11 @@ immer::vector<std::string>
 fizzbuzz(immer::vector<std::string> v, int first, int last)
 {
     for (auto i = first; i < last; ++i)
-        v = std::move(v).push_back(
-            i % 15 == 0 ? "FizzBuzz"
-                        : i % 5 == 0 ? "Bizz"
-                                     : i % 3 == 0 ? "Fizz" :
-                                                  /* else */ std::to_string(i));
+        v = std::move(v).push_back(i % 15 == 0  ? "FizzBuzz"
+                                   : i % 5 == 0 ? "Bizz"
+                                   : i % 3 == 0 ? "Fizz"
+                                                :
+                                                /* else */ std::to_string(i));
     return v;
 }
 // include:fizzbuzz/end
