@@ -14,7 +14,7 @@
 #include <immer/map.hpp>
 #include <immer/refcount/no_refcount_policy.hpp>
 
-#include <catch2/catch.hpp>
+#include <catch2/catch_test_macros.hpp>
 
 using gc_memory = immer::memory_policy<immer::heap_policy<immer::gc_heap>,
                                        immer::no_refcount_policy,
