@@ -16,7 +16,7 @@
 
 #include <array>
 
-#include <catch2/catch.hpp>
+#include <catch2/catch_test_macros.hpp>
 
 #define IMMER_FUZZED_TRACE_ENABLE 1
 
